# Contributor Friendliness Assessment

a clear description
a quick example in the readme
description of use cases
direct link to docs by the description
who is the audience?
Is there a wider audience?
What can we compare to?

